==> censys_cloud_connectors-3.1.0b3.tar.gz: censys_cloud_connectors-3.1.0b3/README.md <==
# Censys Unified Cloud Connector

[![GitHub release (latest by date)](https://img.shields.io/github/v/release/censys/censys-cloud-connector)][github]
[![PyPI - License](https://img.shields.io/pypi/l/censys-cloud-connectors)][license]
[![AWS Supported](https://img.shields.io/badge/-Supported-orange?logo=amazonaws)][aws]
[![Azure Supported](https://img.shields.io/badge/-Supported-green?logo=microsoftazure)][azure]
[![GCP Supported](https://img.shields.io/badge/-Supported-blue?logo=googlecloud&logoColor=white)][gcp]

The Censys Unified Cloud Connector is a standalone connector that gathers
assets from various cloud providers and stores them in Censys ASM. This
Connector offers users the ability to supercharge our ASM Platform with total
cloud visibility. This connector currently supports the following cloud
providers: AWS, Azure, and GCP. Please see our
[supported providers][supported-providers].

## Documentation

Please view our documentation on [Read the Docs][censys-cloud-connector-docs].

## Contributing

All contributions (no matter how small) are always welcome. See
[Contributing to the Cloud Connector][contributing] to change or
test the code or for information on the CI/CD pipeline.

Submit an issue or pull request on [GitHub][github-issues].

## License

This software is licensed under [Apache License, Version 2.0][license].

- Copyright (C) 2023 Censys, Inc.

<!-- References -->

[aws]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html#amazon-web-services
[azure]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html#azure-cloud
[censys-cloud-connector-docs]: https://censys-cloud-connector.readthedocs.io/en/stable/
[contributing]: https://github.com/censys/censys-cloud-connector/tree/main/CONTRIBUTING.md
[gcp]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html#google-cloud-platform
[github]: https://github.com/censys/censys-cloud-connector
[github-issues]: https://github.com/censys/censys-cloud-connector/issues
[license]: http://www.apache.org/licenses/LICENSE-2.0
[supported-providers]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html

==> censys_cloud_connectors-3.1.3.tar.gz: censys_cloud_connectors-3.1.3/README.md <==
# Censys Unified Cloud Connector

[![GitHub release (latest by date)](https://img.shields.io/github/v/release/censys/censys-cloud-connector)][github]
[![PyPI - License](https://img.shields.io/pypi/l/censys-cloud-connectors)][license]
[![AWS Supported](https://img.shields.io/badge/-Supported-orange?logo=amazonaws)][aws]
[![Azure Supported](https://img.shields.io/badge/-Supported-green?logo=microsoftazure)][azure]
[![GCP Supported](https://img.shields.io/badge/-Supported-blue?logo=googlecloud&logoColor=white)][gcp]

The Censys Unified Cloud Connector is a standalone connector that gathers
assets from various cloud providers and stores them in Censys ASM. This
Connector offers users the ability to supercharge our ASM Platform with total
cloud visibility. This connector currently supports the following cloud
providers: AWS, Azure, and GCP. Please see our
[supported providers][supported-providers].

## Documentation

Please view our documentation on [Read the Docs][censys-cloud-connector-docs].

## Contributing

All contributions (no matter how small) are always welcome. See
[Contributing to the Cloud Connector][contributing] to change or
test the code or for information on the CI/CD pipeline.

Submit an issue or pull request on [GitHub][github-issues].

## License

This software is licensed under [Apache License, Version 2.0][license].

- Copyright (C) 2023 Censys, Inc.

<!-- References -->

[aws]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html#amazon-web-services
[azure]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html#azure-cloud
[censys-cloud-connector-docs]: https://censys-cloud-connector.rtfd.io/
[contributing]: https://github.com/censys/censys-cloud-connector/tree/main/CONTRIBUTING.md
[gcp]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html#google-cloud-platform
[github]: https://github.com/censys/censys-cloud-connector
[github-issues]: https://github.com/censys/censys-cloud-connector/issues
[license]: http://www.apache.org/licenses/LICENSE-2.0
[supported-providers]: https://censys-cloud-connector.readthedocs.io/en/stable/providers.html
